@@ -56,6 +56,7 @@
 #include <stdexcept>
 #include <vector>
 #include <iostream>
+#include <set>
 
 void ginac_pyinit_Integer(PyObject*);
 void ginac_pyinit_Float(PyObject*);
@@ -188,6 +189,8 @@ public:
 	int csgn() const;
 	bool is_equal(const numeric &other) const;
 	bool is_zero() const;
+	bool is_one() const;
+	bool is_minus_one() const;
 	bool is_positive() const;
 	bool is_negative() const;
 	bool is_integer() const;
@@ -268,6 +271,8 @@ public:
 	const numeric fibonacci() const;
 	const numeric isqrt() const;
 	const numeric sqrt() const;
+        bool is_square() const;
+        const ex sqrt_as_ex() const;
 	const numeric abs() const;
 	const numeric mod(const numeric &b) const;
 	const numeric _smod(const numeric &b) const;
@@ -277,6 +282,8 @@ public:
 	const numeric iquo(const numeric &b, numeric &r) const;
 	const numeric gcd(const numeric &b) const;
 	const numeric lcm(const numeric &b) const;
+        void factor(std::vector<std::pair<long, int>>& factors) const;
+        void divisors(std::set<int>& divs) const;
 	
 	int int_length() const;
 
@@ -338,6 +345,7 @@ const numeric psi(const numeric &x);
 const numeric psi(const numeric &n, const numeric &x);
 const numeric factorial(const numeric &n);
 const numeric doublefactorial(const numeric &n);
+const numeric binomial(unsigned long n, unsigned long k);
 const numeric binomial(const numeric &n, const numeric &k);
 const numeric bernoulli(const numeric &n);
 const numeric hypergeometric_pFq(const std::vector<numeric>& a, const std::vector<numeric>& b, const numeric &z, PyObject* parent);
